@@ -79,7 +79,7 @@ class Filter(MetricsLayerBase):
             "<": MetricsLayerFilterExpressionType.LessThan,
         }
 
-        # Handle null conditiona
+        # Handle null conditional
         if value == "NULL":
             expression = MetricsLayerFilterExpressionType.IsNull
             cleaned_value = None
@@ -88,6 +88,11 @@ class Filter(MetricsLayerBase):
             expression = MetricsLayerFilterExpressionType.IsNotNull
             cleaned_value = None
 
+        # Handle boolean True and False
+        elif value == True or value == False:  # noqa
+            expression = MetricsLayerFilterExpressionType.EqualTo
+            cleaned_value = value
+
         # isin for strings
         elif len(value.split(", ")) > 1:
             if all(category[0] == "-" for category in value.split(", ")):
@@ -140,6 +145,10 @@ class Filter(MetricsLayerBase):
                 categories = ",".join([f"'{v}'" for v in parsed_value])
                 condition_value = f"is not in ({categories})"
 
+            # Handle boolean True and False
+            elif parsed_value == True or parsed_value == False:  # noqa
+                condition_value = f"is {str(parsed_value).upper()}"
+
             # Not equal to condition for strings
             elif f["value"][0] == "-":
                 condition_value = f"<> '{parsed_value}'"
